@@ -13,6 +13,7 @@ import numpy as np
 import verde as vd
 import xarray as xr
 
+from ..visualization.prism import prism_to_pyvista
 from .prism import prism_gravity
 
 
@@ -304,7 +305,9 @@ class DatasetAccessorPrismLayer:
         self._obj.coords["top"] = (self.dims, top)
         self._obj.coords["bottom"] = (self.dims, bottom)
 
-    def gravity(self, coordinates, field, density_name="density", **kwargs):
+    def gravity(
+        self, coordinates, field, progressbar=False, density_name="density", **kwargs
+    ):
         """
         Computes the gravity generated by the layer of prisms
 
@@ -357,6 +360,7 @@ class DatasetAccessorPrismLayer:
             prisms=boundaries,
             density=density,
             field=field,
+            progressbar=progressbar,
             **kwargs,
         )
 
@@ -446,3 +450,22 @@ class DatasetAccessorPrismLayer:
         bottom = self._obj.bottom.values[indices]
         top = self._obj.top.values[indices]
         return west, east, south, north, bottom, top
+
+    def to_pyvista(self):
+        """
+        Return a pyvista UnstructuredGrid to plot the PrismLayer
+
+        Returns
+        -------
+        pv_grid : :class:`pyvista.UnstructuredGrid`
+            :class:`pyvista.UnstructuredGrid` containing each prism of the
+            layer as a hexahedron along with their properties.
+        """
+        prisms = self._to_prisms()
+        properties = None
+        if self._obj.data_vars:
+            properties = {
+                data_var: np.asarray(self._obj[data_var]).ravel()
+                for data_var in self._obj.data_vars
+            }
+        return prism_to_pyvista(prisms, properties=properties)
