@@ -120,12 +120,12 @@ def test_equivalent_sources_cartesian(region, points, masses, coordinates, data)
     # to synthetic values
     upward = 0
     shape = (60, 60)
-    grid = vd.grid_coordinates(region=region, shape=shape, extra_coords=upward)
-    true = point_gravity(grid, points, masses, field="g_z")
-    npt.assert_allclose(true, eqs.predict(grid), rtol=1e-3)
+    grid_coords = vd.grid_coordinates(region=region, shape=shape, extra_coords=upward)
+    true = point_gravity(grid_coords, points, masses, field="g_z")
+    npt.assert_allclose(true, eqs.predict(grid_coords), rtol=1e-3)
 
     # Test grid method
-    grid = eqs.grid(upward, shape=shape, region=region)
+    grid = eqs.grid(grid_coords)
     npt.assert_allclose(true, grid.scalars, rtol=1e-3)
 
     # Test profile method
@@ -155,12 +155,12 @@ def test_equivalent_sources_cartesian_float32(
     # to synthetic values
     upward = 0
     shape = (60, 60)
-    grid = vd.grid_coordinates(region=region, shape=shape, extra_coords=upward)
-    true = point_gravity(grid, points, masses, field="g_z")
-    npt.assert_allclose(true, eqs.predict(grid), atol=1e-3 * vd.maxabs(true))
+    grid_coords = vd.grid_coordinates(region=region, shape=shape, extra_coords=upward)
+    true = point_gravity(grid_coords, points, masses, field="g_z")
+    npt.assert_allclose(true, eqs.predict(grid_coords), atol=1e-3 * vd.maxabs(true))
 
     # Test grid method
-    grid = eqs.grid(upward, shape=shape, region=region)
+    grid = eqs.grid(grid_coords)
     npt.assert_allclose(true, grid.scalars, atol=1e-3 * vd.maxabs(true))
 
     # Test profile method
@@ -197,12 +197,12 @@ def test_equivalent_sources_small_data_cartesian(region, points, masses):
     # to synthetic values
     upward = 20
     shape = (8, 8)
-    grid = vd.grid_coordinates(region=region, shape=shape, extra_coords=upward)
-    true = point_gravity(grid, points, masses, field="g_z")
-    npt.assert_allclose(true, eqs.predict(grid), rtol=0.08)
+    grid_coords = vd.grid_coordinates(region=region, shape=shape, extra_coords=upward)
+    true = point_gravity(grid_coords, points, masses, field="g_z")
+    npt.assert_allclose(true, eqs.predict(grid_coords), rtol=0.08)
 
     # Test grid method
-    grid = eqs.grid(upward, shape=shape, region=region)
+    grid = eqs.grid(grid_coords)
     npt.assert_allclose(true, grid.scalars, rtol=0.08)
 
     # Test profile method
@@ -393,7 +393,7 @@ def test_equivalent_sources_jacobian_cartesian():
 
 
 @run_only_with_numba
-def test_equivalent_sources_cartesian_parallel(region, coordinates, data):
+def test_equivalent_sources_cartesian_parallel(coordinates, data):
     """
     Check predictions when parallel is enabled and disabled
     """
@@ -403,10 +403,8 @@ def test_equivalent_sources_cartesian_parallel(region, coordinates, data):
     eqs_parallel = EquivalentSources(parallel=True)
     eqs_parallel.fit(coordinates, data)
 
-    upward = 0
-    shape = (60, 60)
-    grid_serial = eqs_serial.grid(upward, shape=shape, region=region)
-    grid_parallel = eqs_parallel.grid(upward, shape=shape, region=region)
+    grid_serial = eqs_serial.grid(coordinates)
+    grid_parallel = eqs_parallel.grid(coordinates)
     npt.assert_allclose(grid_serial.scalars, grid_parallel.scalars, rtol=1e-7)
 
 
@@ -432,10 +430,8 @@ def test_backward_eqlharmonic(region, coordinates_small, data_small, depth_type)
     # Check if both gridders are equivalent
     npt.assert_allclose(eqs.points_, eql_harmonic.points_)
     shape = (8, 8)
-    xrt.assert_allclose(
-        eqs.grid(upward=2e3, shape=shape, region=region),
-        eql_harmonic.grid(upward=2e3, shape=shape, region=region),
-    )
+    grid_coords = vd.grid_coordinates(region=region, shape=shape, extra_coords=2e3)
+    xrt.assert_allclose(eqs.grid(grid_coords), eql_harmonic.grid(grid_coords))
 
 
 @run_only_with_numba
@@ -502,3 +498,40 @@ def test_jacobian_dtype(region, dtype):
     jacobian = eqs.jacobian(coordinates, points)
     # Check data type of the Jacobian
     assert jacobian.dtype == np.dtype(dtype)
+
+
+@pytest.mark.parametrize(
+    "deprecated_args",
+    (
+        dict(upward=5e3, spacing=1),
+        dict(upward=5e3, shape=(6, 6)),
+        dict(upward=5e3, spacing=1, region=(-4e3, 0, 5e3, 7e3)),
+        dict(upward=5e3, shape=(6, 6), region=(-4e3, 0, 5e3, 7e3)),
+    ),
+)
+def test_error_deprecated_args(coordinates_small, data_small, region, deprecated_args):
+    """
+    Test if EquivalentSources.grid raises error on deprecated arguments
+    """
+    # Define sample equivalent sources and fit against synthetic data
+    eqs = EquivalentSources().fit(coordinates_small, data_small)
+    # Build a target grid
+    grid_coords = vd.grid_coordinates(region=region, shape=(4, 4), extra_coords=2e3)
+    # Try to grid passing deprecated arguments
+    msg = "The 'upward', 'region', 'shape' and 'spacing' arguments have been"
+    with pytest.raises(ValueError, match=msg):
+        eqs.grid(coordinates=grid_coords, **deprecated_args)
+
+
+def test_error_ignored_args(coordinates_small, data_small, region):
+    """
+    Test if EquivalentSources.grid raises warning on ignored arguments
+    """
+    # Define sample equivalent sources and fit against synthetic data
+    eqs = EquivalentSources().fit(coordinates_small, data_small)
+    # Build a target grid
+    grid_coords = vd.grid_coordinates(region=region, shape=(4, 4), extra_coords=2e3)
+    # Try to grid passing kwarg arguments that will be ignored
+    msg = "The 'bla' arguments are being ignored."
+    with pytest.warns(FutureWarning, match=msg):
+        eqs.grid(coordinates=grid_coords, bla="bla")
