@@ -8,10 +8,24 @@
 Test functions to create synthetic surveys
 """
 import numpy.testing as npt
+import pytest
 
 from ..synthetic import airborne_survey, ground_survey
 
 
+@pytest.mark.parametrize("synthetic_survey", (airborne_survey, ground_survey))
+def test_deprecation_warning(synthetic_survey):
+    """
+    Checks if deprecation warning is raised
+    """
+    message = "The 'synthetic' module will be deprecated in Harmonica v0.6.0."
+    with pytest.warns(FutureWarning, match=message):
+        synthetic_survey()
+
+
+@pytest.mark.filterwarnings(
+    "ignore:The '(synthetic|datasets)' module will be deprecated:FutureWarning"
+)
 def test_ground_survey():
     """
     Test if the sythetic ground survey returns the expected survey
@@ -29,6 +43,9 @@ def test_ground_survey():
     npt.assert_allclose(survey.height.max(), 2052.2)
 
 
+@pytest.mark.filterwarnings(
+    "ignore:The '(synthetic|datasets)' module will be deprecated:FutureWarning"
+)
 def test_scale_ground_survey():
     """
     Test if synthetic ground survey returns the expected survey after scaled
@@ -45,6 +62,9 @@ def test_scale_ground_survey():
     npt.assert_allclose(survey.height.max(), 2052.2)
 
 
+@pytest.mark.filterwarnings(
+    "ignore:The '(synthetic|datasets)' module will be deprecated:FutureWarning"
+)
 def test_airborne_survey():
     """
     Test if the synthetic airborne survey returns the expected survey
@@ -62,6 +82,9 @@ def test_airborne_survey():
     npt.assert_allclose(survey.height.max(), 1255.0)
 
 
+@pytest.mark.filterwarnings(
+    "ignore:The '(synthetic|datasets)' module will be deprecated:FutureWarning"
+)
 def test_scale_airborne_survey():
     """
     Test if synthetic airborne survey returns the expected survey after scaled
@@ -78,6 +101,9 @@ def test_scale_airborne_survey():
     npt.assert_allclose(survey.height.max(), 1255.0)
 
 
+@pytest.mark.filterwarnings(
+    "ignore:The '(synthetic|datasets)' module will be deprecated:FutureWarning"
+)
 def test_data_region_ground_survey():
     """
     Test if ground survey is changed against a different data_region
@@ -94,6 +120,9 @@ def test_data_region_ground_survey():
     assert survey.height.max() >= 2052.2
 
 
+@pytest.mark.filterwarnings(
+    "ignore:The '(synthetic|datasets)' module will be deprecated:FutureWarning"
+)
 def test_data_region_airborne_survey():
     """
     Test if a different cut_region produces a different airborne survey
