@@ -9,9 +9,29 @@ Decorators and useful functions for running tests
 """
 import os
 
+import numpy as np
 import pytest
 
 
+def root_mean_square_error(x, y):
+    """
+    Compute root mean square error between two arrays
+
+    Parameters
+    ----------
+    x : array
+    y : array
+
+    Returns
+    -------
+    rms : float
+        Root mean square error between the two arrays
+    """
+    x = np.asarray(x)
+    y = np.asarray(y)
+    return np.sqrt(np.mean((x - y) ** 2))
+
+
 def combine_decorators(*decorators):
     """
     Combine several decorators into a single one
